Learn R Programming

rusquant (version 1.1.4)

getSymbols.Gigapack: Download Giga Candles data from GigaPack

Description

Download historical market data from GigaPack for a given symbol and time range.

Usage

getSymbols.Gigapack(
  Symbols,
  env = globalenv(),
  from = Sys.Date() - 30,
  to = Sys.Date(),
  date = "",
  verbose = TRUE,
  field = "",
  type = "candles",
  fake = FALSE,
  reps = 1,
  trim = 0.1,
  auto.assign = FALSE,
  ...
)

Value

returns an data.table object containing financial data

Arguments

Symbols

a character vector of AlgoPack symbols to download data for.

env

environment where to create the downloaded data object.

from

a character string indicating the start date of the data to download, in YYYY-MM-DD format.

to

a character string indicating the end date of the data to download, in YYYY-MM-DD format.

date

a character string indicating the specific date of the data to download, in YYYY-MM-DD format.

verbose

a logical indicating whether to print the response details or not.

field

a character string indicating the GigaPack field

type

a character string indicating the GigaPack field candles or tech

fake

a bool string indicating the Giga Candles or Alter Giga

reps

number of alternative history geneartion

trim

number of entropy in data

auto.assign

a logical indicating whether to automatically assign the downloaded data to the global environment.

...

additional arguments passed to getSymbols.AlgoPack

Author

Vyacheslav Arbuzov

Examples

Run this code
getSymbols.Gigapack('SBER', field = 'disb.q20')

Run the code above in your browser using DataLab