Download historical market data from GigaPack for a given symbol and time range.
getSymbols.Gigapack(
Symbols,
env = globalenv(),
from = Sys.Date() - 30,
to = Sys.Date(),
date = "",
verbose = TRUE,
field = "",
type = "candles",
fake = FALSE,
reps = 1,
trim = 0.1,
auto.assign = FALSE,
...
)returns an data.table object containing financial data
a character vector of AlgoPack symbols to download data for.
environment where to create the downloaded data object.
a character string indicating the start date of the data to download, in YYYY-MM-DD format.
a character string indicating the end date of the data to download, in YYYY-MM-DD format.
a character string indicating the specific date of the data to download, in YYYY-MM-DD format.
a logical indicating whether to print the response details or not.
a character string indicating the GigaPack field
a character string indicating the GigaPack field candles or tech
a bool string indicating the Giga Candles or Alter Giga
number of alternative history geneartion
number of entropy in data
a logical indicating whether to automatically assign the downloaded data to the global environment.
additional arguments passed to getSymbols.AlgoPack
Vyacheslav Arbuzov
getSymbols.Gigapack('SBER', field = 'disb.q20')
Run the code above in your browser using DataLab