- Symbols
A character vector with the names of the symbols to be retrieved.
- from
A character string representing the start date for the financial data, in the format "YYYY-MM-DD". By default, it is "2007-01-01".
- to
A character string representing the end date for the financial data, in the format "YYYY-MM-DD". By default, it is the current system date.
- adjust
A logical value indicating whether to adjust prices for dividends and stock splits. By default, it is FALSE.
- api.key
A character string containing the API key for accessing Tinkoff API.
- period
A character string representing the interval of time between two candles. By default it is "day".
- market
A character string representing the market to which the symbol belongs. By default, it is NULL.
- verbose
A logical value indicating whether to print verbose output. By default, it is FALSE.
- auto.assign
A logical value indicating whether to automatically assign the downloaded data to an object with the same name as the symbol. By default, it is FALSE.
- ...
Additional arguments.